.. module:: enaml.applib.live_editor_model

==============================
enaml.applib.live_editor_model
==============================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    LiveEditorModel


.. autoclass:: LiveEditorModel
